
window.downloadFileFromStream = async (fileName, contentStreamReference) => {
    const arrayBuffer = await contentStreamReference.arrayBuffer();
    const blob = new Blob([arrayBuffer]);
    const url = URL.createObjectURL(blob);
    const anchorElement = document.createElement('a');
    anchorElement.href = url;
    anchorElement.download = fileName ?? '';
    anchorElement.click();
    anchorElement.remove();
    URL.revokeObjectURL(url);
}

window.renderPatchPreviewOnCanvas = (canvas, sourceWidth, sourceHeight, patchPositionX, patchPositionY, patchWidth, patchHeight) => {
    const ctx = canvas.getContext("2d");
    const canvasWidth = canvas.width;
    const canvasHeight = canvas.height;

    ctx.clearRect(0, 0, canvasWidth, canvasHeight);

    // Determine the proper scale regarding the canvas and scale input dimensions.
    const scale = Math.min(canvasWidth / sourceWidth, canvasHeight / sourceHeight);
    const scaledSourceWidth = scale * sourceWidth;
    const scaledSourceHeight = scale * sourceHeight;
    const scaledPatchPositionX = scale * patchPositionX;
    const scaledPatchPositionY = scale * patchPositionY;
    const scaledPatchWidth = scale * patchWidth;
    const scaledPatchHeight = scale * patchHeight;

    // Determine the placement of the source canvas within the canvas.
    const offsetX= (canvasWidth - scaledSourceWidth) / 2;
    const offsetY = (canvasHeight - scaledSourceHeight) / 2;

    // Draw source canvas first.
    ctx.beginPath();
    ctx.fillStyle = "#1a1d20";
    ctx.rect(offsetX, offsetY, scaledSourceWidth, scaledSourceHeight);
    ctx.fill();

    // Then place patch on top of it.
    ctx.beginPath();
    ctx.fillStyle = "#343a40";
    ctx.rect(offsetX + scaledPatchPositionX, offsetY + scaledPatchPositionY, scaledPatchWidth, scaledPatchHeight);
    ctx.fill();
}
