#!/bin/bash
stageCliPath="Bin/Cli/StageCli"
stageAgentPath="Bin/Agent/StageAgent"

function getLibraryPath()
{
    retval="$(ldconfig -p | grep $1 | tr ' ' '\n' | grep /)"
}

function linkLibrary()
{
    if [ ! -f Bin/Cli/$1 ]
    then
        getLibraryPath $1
        local libraryPath=$retval

        if [ ! -f $libraryPath ]
        then
            echo "ERROR: Could not find required native library '$1'."
            exit 1
        fi

        ln -s $libraryPath Bin/Cli/$1
        ln -s $libraryPath Bin/Agent/$1
    fi
}

# Make sure all required native libaries are properly linked. 
linkLibrary libopenal.so

# Make sure that DISPLAY has been exported, default to first local screen otherwise. 
if [ -z "$DISPLAY" ]; then
    export DISPLAY=:0
fi

# Make sure executables are actually executable. 
chmod +x $stageCliPath
chmod +x $stageAgentPath

# Forward command to CLI executable. 
./$stageCliPath $@

# Install stage update, if required. 
if [ $? -eq 100 ]
then
    echo Installing stage update ...
    rm -r Bin
    mv Update/Bin .
    cp -rf Update/Extensions .
    mv Update/agent.sh agentNew.sh

    echo Finishing stage update ...
    chmod +x $stageCliPath
    chmod +x $stageAgentPath
    chmod +x agentNew.sh

    ./agentNew.sh update --finish
    
    mv -f agentNew.sh agent.sh
    exit 0
fi
